"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.AliasAssetRequestResolver = void 0;
var _clientDynamodb = require("@webiny/aws-sdk/client-dynamodb");
var _ = require("./..");
class AliasAssetRequestResolver {
  constructor(documentClient, resolver) {
    this.documentClient = documentClient;
    this.resolver = resolver;
  }
  async resolve(request) {
    const resolvedAsset = await this.resolver.resolve(request);
    if (resolvedAsset) {
      return resolvedAsset;
    }
    const params = request.params ?? {};
    const query = request.query ?? {};
    const path = decodeURI(params["*"]);
    const tenant = query.tenant || "root";
    const fileKey = await this.getFileByAlias(tenant, path);
    if (!fileKey) {
      return undefined;
    }
    const {
      original,
      ...options
    } = query;
    return new _.AssetRequest({
      key: fileKey,
      context: {
        url: request.url
      },
      options: {
        original: original !== undefined,
        ...options
      }
    });
  }
  async getFileByAlias(tenant, alias) {
    const {
      Items
    } = await this.documentClient.send(new _clientDynamodb.QueryCommand({
      TableName: String(process.env.DB_TABLE),
      IndexName: "GSI1",
      Limit: 1,
      KeyConditionExpression: "GSI1_PK = :GSI1_PK AND GSI1_SK = :GSI1_SK",
      ExpressionAttributeValues: {
        ":GSI1_PK": {
          S: `T#${tenant}#FM#FILE_ALIASES`
        },
        ":GSI1_SK": {
          S: alias
        }
      }
    }));
    if (!Array.isArray(Items)) {
      return null;
    }
    const [item] = Items;
    if (!item) {
      return null;
    }
    const {
      data
    } = (0, _clientDynamodb.unmarshall)(item);
    return data?.key ?? null;
  }
}
exports.AliasAssetRequestResolver = AliasAssetRequestResolver;

//# sourceMappingURL=AliasAssetRequestResolver.js.map