import { Plugin } from "@webiny/plugins";
import { AssetRequestResolver, AssetResolver, AssetProcessor, AssetOutputStrategy, AssetRequest, Asset, AssetTransformationStrategy, ResponseHeadersSetter } from "..";
import { FileManagerContext } from "../../types";
declare type Setter<TParams, TReturn> = (params: TParams) => TReturn;
export declare type AssetRequestResolverDecorator = Setter<{
    assetRequestResolver: AssetRequestResolver;
}, AssetRequestResolver>;
export declare type AssetResolverDecorator = Setter<{
    assetResolver: AssetResolver;
}, AssetResolver>;
export declare type AssetProcessorDecorator = Setter<{
    context: FileManagerContext;
    assetProcessor: AssetProcessor;
}, AssetProcessor>;
export declare type AssetTransformationDecorator = Setter<{
    context: FileManagerContext;
    assetTransformationStrategy: AssetTransformationStrategy;
}, AssetTransformationStrategy>;
export interface AssetOutputStrategyDecoratorParams {
    context: FileManagerContext;
    assetRequest: AssetRequest;
    asset: Asset;
    assetOutputStrategy: AssetOutputStrategy;
}
export declare type AssetOutputStrategyDecorator = Setter<AssetOutputStrategyDecoratorParams, AssetOutputStrategy>;
export declare class AssetDeliveryConfigBuilder {
    private assetRequestResolverDecorators;
    private assetResolverDecorators;
    private assetProcessorDecorators;
    private assetTransformationStrategyDecorators;
    private assetOutputStrategyDecorators;
    setResponseHeaders(setter: ResponseHeadersSetter): void;
    decorateAssetRequestResolver(decorator: AssetRequestResolverDecorator): void;
    decorateAssetResolver(decorator: AssetResolverDecorator): void;
    decorateAssetProcessor(decorator: AssetProcessorDecorator): void;
    decorateAssetTransformationStrategy(decorator: AssetTransformationDecorator): void;
    decorateAssetOutputStrategy(decorator: AssetOutputStrategyDecorator): void;
    /**
     * @internal
     */
    getAssetRequestResolver(): AssetRequestResolver;
    /**
     * @internal
     */
    getAssetResolver(): AssetResolver;
    /**
     * @internal
     */
    getAssetProcessor(context: FileManagerContext): AssetProcessor;
    getAssetOutputStrategy(context: FileManagerContext, assetRequest: AssetRequest, asset: Asset): AssetOutputStrategy;
    getAssetTransformationStrategy(context: FileManagerContext): AssetTransformationStrategy;
}
export interface AssetDeliveryConfigModifier {
    (config: AssetDeliveryConfigBuilder): Promise<void> | void;
}
export declare class AssetDeliveryConfigModifierPlugin extends Plugin {
    static type: string;
    private readonly cb;
    constructor(cb: AssetDeliveryConfigModifier);
    buildConfig(configBuilder: AssetDeliveryConfigBuilder): Promise<void>;
}
export declare const createAssetDeliveryConfig: (cb: AssetDeliveryConfigModifier) => AssetDeliveryConfigModifierPlugin;
export {};
