"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createAssetDeliveryConfig = exports.AssetDeliveryConfigModifierPlugin = exports.AssetDeliveryConfigBuilder = void 0;
var _plugins = require("@webiny/plugins");
var _ = require("./..");
var _NullRequestResolver = require("./NullRequestResolver");
var _NullAssetResolver = require("./NullAssetResolver");
var _NullAssetOutputStrategy = require("./NullAssetOutputStrategy");
var _TransformationAssetProcessor = require("./transformation/TransformationAssetProcessor");
var _PassthroughAssetTransformationStrategy = require("./transformation/PassthroughAssetTransformationStrategy");
class AssetDeliveryConfigBuilder {
  assetRequestResolverDecorators = [];
  assetResolverDecorators = [];
  assetProcessorDecorators = [];
  assetTransformationStrategyDecorators = [];
  assetOutputStrategyDecorators = [];
  setResponseHeaders(setter) {
    this.decorateAssetOutputStrategy(params => {
      return new _.SetResponseHeaders(setter, params);
    });
  }
  decorateAssetRequestResolver(decorator) {
    this.assetRequestResolverDecorators.push(decorator);
  }
  decorateAssetResolver(decorator) {
    this.assetResolverDecorators.push(decorator);
  }
  decorateAssetProcessor(decorator) {
    this.assetProcessorDecorators.push(decorator);
  }
  decorateAssetTransformationStrategy(decorator) {
    this.assetTransformationStrategyDecorators.push(decorator);
  }
  decorateAssetOutputStrategy(decorator) {
    this.assetOutputStrategyDecorators.push(decorator);
  }

  /**
   * @internal
   */
  getAssetRequestResolver() {
    return this.assetRequestResolverDecorators.reduce((value, decorator) => decorator({
      assetRequestResolver: value
    }), new _NullRequestResolver.NullRequestResolver());
  }

  /**
   * @internal
   */
  getAssetResolver() {
    return this.assetResolverDecorators.reduce((value, decorator) => decorator({
      assetResolver: value
    }), new _NullAssetResolver.NullAssetResolver());
  }

  /**
   * @internal
   */
  getAssetProcessor(context) {
    return this.assetProcessorDecorators.reduce((value, decorator) => decorator({
      assetProcessor: value,
      context
    }), new _TransformationAssetProcessor.TransformationAssetProcessor(this.getAssetTransformationStrategy(context)));
  }
  getAssetOutputStrategy(context, assetRequest, asset) {
    return this.assetOutputStrategyDecorators.reduce((value, decorator) => {
      return decorator({
        context,
        assetRequest,
        asset,
        assetOutputStrategy: value
      });
    }, new _NullAssetOutputStrategy.NullAssetOutputStrategy());
  }
  getAssetTransformationStrategy(context) {
    return this.assetTransformationStrategyDecorators.reduce((value, decorator) => decorator({
      context,
      assetTransformationStrategy: value
    }), new _PassthroughAssetTransformationStrategy.PassthroughAssetTransformationStrategy());
  }
}
exports.AssetDeliveryConfigBuilder = AssetDeliveryConfigBuilder;
class AssetDeliveryConfigModifierPlugin extends _plugins.Plugin {
  static type = "fm.config-modifier";
  constructor(cb) {
    super();
    this.cb = cb;
  }
  async buildConfig(configBuilder) {
    await this.cb(configBuilder);
  }
}
exports.AssetDeliveryConfigModifierPlugin = AssetDeliveryConfigModifierPlugin;
const createAssetDeliveryConfig = cb => {
  return new AssetDeliveryConfigModifierPlugin(cb);
};
exports.createAssetDeliveryConfig = createAssetDeliveryConfig;

//# sourceMappingURL=AssetDeliveryConfig.js.map