"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createBaseSchema = void 0;
var _handlerGraphql = require("@webiny/handler-graphql");
var _utils = require("./utils");
const createBaseSchema = () => {
  const fileManagerGraphQL = new _handlerGraphql.GraphQLSchemaPlugin({
    typeDefs: /* GraphQL */`
            type FmError {
                code: String
                message: String
                data: JSON
                stack: String
            }

            type FmCreatedBy {
                id: ID
                displayName: String
                type: String
            }

            type FmListMeta {
                cursor: String
                totalCount: Int
                hasMoreItems: Boolean
            }

            type FmBooleanResponse {
                data: Boolean
                error: FmError
            }

            type FmSettings {
                uploadMinFileSize: Number
                uploadMaxFileSize: Number
                srcPrefix: String
            }

            input FmSettingsInput {
                uploadMinFileSize: Number
                uploadMaxFileSize: Number
                srcPrefix: String
            }

            type FmSettingsResponse {
                data: FmSettings
                error: FmError
            }

            type FmQuery {
                version: String
                getSettings: FmSettingsResponse
            }

            type FmDeleteResponse {
                data: Boolean
                error: FmError
            }

            type FmMutation {
                install(srcPrefix: String): FmBooleanResponse
                updateSettings(data: FmSettingsInput): FmSettingsResponse
            }

            input FmInstallInput {
                srcPrefix: String!
            }

            extend type Query {
                fileManager: FmQuery
            }

            extend type Mutation {
                fileManager: FmMutation
            }
        `,
    resolvers: {
      Query: {
        fileManager: _utils.emptyResolver
      },
      Mutation: {
        fileManager: _utils.emptyResolver
      },
      FmQuery: {
        async version(_, __, context) {
          const {
            i18n,
            tenancy,
            fileManager
          } = context;
          if (!tenancy.getCurrentTenant() || !i18n.getContentLocale()) {
            return null;
          }
          return await fileManager.getVersion();
        },
        async getSettings(_, __, context) {
          return (0, _utils.resolve)(() => context.fileManager.getSettings());
        }
      },
      FmMutation: {
        async install(_, args, context) {
          return (0, _utils.resolve)(() => context.fileManager.install({
            srcPrefix: args.srcPrefix
          }));
        },
        async updateSettings(_, args, context) {
          return (0, _utils.resolve)(() => context.fileManager.updateSettings(args.data));
        }
      }
    }
  });
  fileManagerGraphQL.name = "fm.graphql.base";
  return fileManagerGraphQL;
};
exports.createBaseSchema = createBaseSchema;

//# sourceMappingURL=baseSchema.js.map