"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createGraphQLSchemaPlugin = void 0;
var _baseSchema = require("./baseSchema");
var _api = require("@webiny/api");
var _createFieldTypePluginRecords = require("@webiny/api-headless-cms/graphql/schema/createFieldTypePluginRecords");
var _getSchemaFromFieldPlugins = require("@webiny/api-headless-cms/utils/getSchemaFromFieldPlugins");
var _handlerGraphql = require("@webiny/handler-graphql");
var _filesSchema = require("./filesSchema");
var _isInstallationPending = require("../cmsFileStorage/isInstallationPending");
var _getFileByUrl = require("./getFileByUrl");
const createGraphQLSchemaPlugin = () => {
  return [(0, _baseSchema.createBaseSchema)(),
  // Files schema is generated dynamically, based on a CMS model, so we need to
  // register it from a ContextPlugin, to perform additional bootstrap.
  new _api.ContextPlugin(async context => {
    if ((0, _isInstallationPending.isInstallationPending)(context)) {
      return;
    }
    await context.security.withoutAuthorization(async () => {
      const fileModel = await context.cms.getModel("fmFile");
      const models = await context.cms.listModels();
      const fieldPlugins = (0, _createFieldTypePluginRecords.createFieldTypePluginRecords)(context.plugins);
      /**
       * We need to register all plugins for all the CMS fields.
       */
      const plugins = (0, _getSchemaFromFieldPlugins.createGraphQLSchemaPluginFromFieldPlugins)({
        models,
        type: "manage",
        fieldTypePlugins: fieldPlugins,
        createPlugin: ({
          schema,
          type,
          fieldType
        }) => {
          const plugin = new _handlerGraphql.GraphQLSchemaPlugin(schema);
          plugin.name = `fm.graphql.schema.${type}.field.${fieldType}`;
          return plugin;
        }
      });
      const graphQlPlugin = (0, _filesSchema.createFilesSchema)({
        model: fileModel,
        models,
        plugins: fieldPlugins
      });
      context.plugins.register([...plugins, graphQlPlugin, (0, _getFileByUrl.getFileByUrl)()]);
    });
  })];
};
exports.createGraphQLSchemaPlugin = createGraphQLSchemaPlugin;

//# sourceMappingURL=index.js.map